# karp-lex-types

[![PyPI version](https://badge.fury.io/py/karp-lex-types.svg)](https://pypi.org/project/karp-lex-types/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/karp-lex-types)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/karp-lex-types)](https://pypi.org/project/karp-lex-types/)

[![Maturity badge - level 3](https://img.shields.io/badge/Maturity-Level%203%20--%20Stable-green.svg)](https://github.com/spraakbanken/getting-started/blob/main/scorecard.md)
[![Stage](https://img.shields.io/pypi/status/sparv-sbx-word-prediction-kb-bert)](https://pypi.org/project/sparv-sbx-word-prediction-kb-bert/)

[![Code Coverage](https://codecov.io/gh/spraakbanken/karp-lex-types/branch/main/graph/badge.svg)](https://codecov.io/gh/spraakbanken/karp-lex-types/)

[![CI(check)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/check.yml/badge.svg)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/check.yml)
[![CI(release)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/release.yml/badge.svg)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/release.yml)
[![CI(scheduled)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/scheduled.yml/badge.svg)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/scheduled.yml)
[![CI(test)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/test.yml/badge.svg)](https://github.com/spraakbanken/karp-lex-types/actions/workflows/test.yml)

Types for karp-lex. Mainly [`pydantic`](https://docs.pydantic.dev/latest/)-types for easy validation and export of models.

Contains commands, entry_dto and unique_id used in [`karp-backend`](https://github.com/spraakbanken/karp-backend).

Can be used for defining resource models in python that pydantic validates, perfect when creating Karp resources.
